@@ -20,7 +20,7 @@ MLyork <- function(yd,anchor=0,model=1,wtype='a',
             init <- c(b=binit,lw=lwinit)
             lower <- c(min(binit*c(2,1/2)),lwinit-2)
             upper <- c(max(binit*c(2,1/2)),lwinit+2)
-            fit <- contingencyfit(init,LL.MLyork.blw,a=p['a'],
+            fit <- contingencyfit(init,LL_MLyork_blw,a=p['a'],
                                   yd=yd,lower=lower,upper=upper)
             pnames <- c('b','lw')
             p[pnames] <- fit$par
@@ -30,11 +30,11 @@ MLyork <- function(yd,anchor=0,model=1,wtype='a',
             binit <- unname(lmfit$coefficients)
             interval <- sort(binit*c(2,1/2))
             lw <- ifelse(model==3 & length(anchor)>2, log(anchor[3]), -Inf)
-            fit <- stats::optimise(LL.MLyork.b,a=p['a'],lw=lw,
+            fit <- stats::optimise(LL_MLyork_b,a=p['a'],lw=lw,
                                    yd=yd,interval=interval,tol=tol)
             p['b'] <- fit$minimum
             p['lw'] <- lw
-            H <- stats::optimHess(fit$minimum,LL.MLyork.b,
+            H <- stats::optimHess(fit$minimum,LL_MLyork_b,
                                   a=p['a'],lw=lw,yd=yd,control=control)
             E['b','b'] <- inverthess(H)
             E['lw','lw'] <- 0
@@ -53,7 +53,7 @@ MLyork <- function(yd,anchor=0,model=1,wtype='a',
             init <- c(a=ainit,lw=lwinit)
             lower <- c(min(ainit*c(2,1/2)),lwinit-2)
             upper <- c(max(ainit*c(2,1/2)),lwinit+2)
-            fit <- contingencyfit(init,LL.MLyork.alw,b=p['b'],
+            fit <- contingencyfit(init,LL_MLyork_alw,b=p['b'],
                                   yd=yd,lower=lower,upper=upper)
             pnames <- c('a','lw')
             p[pnames] <- fit$par
@@ -62,11 +62,11 @@ MLyork <- function(yd,anchor=0,model=1,wtype='a',
         } else {
             interval <- sort(c(init/2,init*2))
             lw <- ifelse(model==3 & length(anchor)>2, log(anchor[3]), -Inf)
-            fit <- stats::optimise(LL.MLyork.a,init,b=p['b'],lw=lw,
+            fit <- stats::optimise(LL_MLyork_a,init,b=p['b'],lw=lw,
                                    yd=yd,interval=interval,tol=tol)
             p['a'] <- fit$minimum
             p['lw'] <- lw
-            H <- stats::optimHess(fit$minimum,LL.MLyork.a,
+            H <- stats::optimHess(fit$minimum,LL_MLyork_a,
                                   b=p['b'],lw=lw,yd=yd,control=control)
             E['a','a'] <- inverthess(H)
             E['lw','lw'] <- 0
@@ -82,22 +82,22 @@ MLyork <- function(yd,anchor=0,model=1,wtype='a',
             E[i,i] <- fit$cov
         } else if (model==3){
             init <- c(a=ab[1],b=ab[2],lw=0)
-            fit <- stats::optim(init,LL.MLyork.ablw,yd=yd,wtype=wtype,
+            fit <- stats::optim(init,LL_MLyork_ablw,yd=yd,wtype=wtype,
                                 hessian=TRUE,control=control)
             p <- fit$par
             E <- inverthess(fit$hessian)
         } else { # this is equivalent to ordinary York regression
             init <- c(a=ab[1],b=ab[2])
-            fit <- stats::optim(init,LL.MLyork.ab,yd=yd,
+            fit <- stats::optim(init,LL_MLyork_ab,yd=yd,
                                 hessian=TRUE,control=control)
             p[1:2] <- fit$par
             E <- inverthess(fit$hessian)
-            SS <- LL.MLyork.ab(fit$par,yd=yd,returnval='SS')
+            SS <- LL_MLyork_ab(fit$par,yd=yd,returnval='SS')
             df <- ns-2
         }
     }
     if (model==1){
-        SS <- LL.MLyork.ablw(p,yd=yd,returnval='SS')
+        SS <- LL_MLyork_ablw(p,yd=yd,returnval='SS')
         fit <- append(fit,getMSWD(X2=SS,df=df))
     }
     fit$model <- model
@@ -114,32 +114,32 @@ MLyork <- function(yd,anchor=0,model=1,wtype='a',
     fit
 }
 
-LL.MLyork.a <- function(a,b,lw=-Inf,yd,returnval='LL'){
-    LL.MLyork.ablw(c(a,b,lw),yd=yd,returnval=returnval)
+LL_MLyork_a <- function(a,b,lw=-Inf,yd,returnval='LL'){
+    LL_MLyork_ablw(c(a,b,lw),yd=yd,returnval=returnval)
 }
-LL.MLyork.b <- function(b,a,lw=-Inf,yd,returnval='LL'){
-    LL.MLyork.ablw(c(a,b,lw),yd=yd,returnval=returnval)
+LL_MLyork_b <- function(b,a,lw=-Inf,yd,returnval='LL'){
+    LL_MLyork_ablw(c(a,b,lw),yd=yd,returnval=returnval)
 }
-LL.MLyork.ab <- function(ab,lw=-Inf,yd,returnval='LL'){
-    LL.MLyork.ablw(c(ab,lw),yd=yd,returnval=returnval)
+LL_MLyork_ab <- function(ab,lw=-Inf,yd,returnval='LL'){
+    LL_MLyork_ablw(c(ab,lw),yd=yd,returnval=returnval)
 }
-LL.MLyork.alw <- function(alw,b,yd,returnval='LL'){
-    LL.MLyork.ablw(c(alw[1],b,alw[2]),yd=yd,
+LL_MLyork_alw <- function(alw,b,yd,returnval='LL'){
+    LL_MLyork_ablw(c(alw[1],b,alw[2]),yd=yd,
                    wtype='b',returnval=returnval)
 }
-LL.MLyork.blw <- function(blw,a,yd,returnval='LL'){
-    LL.MLyork.ablw(c(a,blw),yd=yd,
+LL_MLyork_blw <- function(blw,a,yd,returnval='LL'){
+    LL_MLyork_ablw(c(a,blw),yd=yd,
                    wtype='a',returnval=returnval)
 }
-LL.MLyork.ablw <- function(ablw,yd,wtype='a',returnval='LL'){
+LL_MLyork_ablw <- function(ablw,yd,wtype='a',returnval='LL'){
     a <- ablw[1]
     b <- ablw[2]
     w <- exp(ablw[3])
     if (wtype%in%c(2,'slope','b')){
         misfit <- function(x,yd,a,b,w,SS=FALSE){
-            E <- MLY.getE(yd=yd,w=w,wtype=wtype,x=x)
-            O <- MLY.getO(E)
-            S <- MLY.maha(a=a,b=b,x=x,X=yd[,'X'],Y=yd[,'Y'],O=O)
+            E <- MLY_getE(yd=yd,w=w,wtype=wtype,x=x)
+            O <- MLY_getO(E)
+            S <- MLY_maha(a=a,b=b,x=x,X=yd[,'X'],Y=yd[,'Y'],O=O)
             if (SS) return(sum(S))
             detE <- E[,1]*E[,2]-E[,3]^2
             sum(log(detE)+S)/2
@@ -156,8 +156,8 @@ LL.MLyork.ablw <- function(ablw,yd,wtype='a',returnval='LL'){
     } else { # wtype%in%c(1,'intercept','a')
         X <- yd[,'X']
         Y <- yd[,'Y']
-        E <- MLY.getE(yd=yd,w=w,wtype=wtype)
-        O <- MLY.getO(E)
+        E <- MLY_getE(yd=yd,w=w,wtype=wtype)
+        O <- MLY_getO(E)
         O11 <- O[,1]; O22 <- O[,2]; O12 <- O[,3]
         num <- -((O22*a-O22*Y-O12*X)*b+O12*a-O12*Y-O11*X)
         den <- O22*b^2+2*O12*b+O11
@@ -165,8 +165,8 @@ LL.MLyork.ablw <- function(ablw,yd,wtype='a',returnval='LL'){
         if (returnval=='x'){
             out <- x
         } else {
-            Ew <- MLY.getE(yd,w=w,wtype=wtype,x=x)
-            S <- MLY.maha(a=a,b=b,x=x,X=yd[,'X'],Y=yd[,'Y'],O=MLY.getO(Ew))
+            Ew <- MLY_getE(yd,w=w,wtype=wtype,x=x)
+            S <- MLY_maha(a=a,b=b,x=x,X=yd[,'X'],Y=yd[,'Y'],O=MLY_getO(Ew))
             if (returnval=='SS'){
                 out <- sum(S)
             } else {
@@ -177,7 +177,7 @@ LL.MLyork.ablw <- function(ablw,yd,wtype='a',returnval='LL'){
     }
 }
 
-MLY.getE <- function(yd,w=0,wtype='a',x=0){
+MLY_getE <- function(yd,w=0,wtype='a',x=0){
     E11 <- yd[,'sX']^2
     E22 <- yd[,'sY']^2
     E12 <- yd[,'rXY']*yd[,'sX']*yd[,'sY']
@@ -185,10 +185,10 @@ MLY.getE <- function(yd,w=0,wtype='a',x=0){
     else E22 <- E22 + w^2
     cbind(E11,E22,E12)
 }
-MLY.getO <- function(E){
+MLY_getO <- function(E){
     invertcovmat(vx=E[,1],vy=E[,2],sxy=E[,3])
 }
-MLY.maha <- function(yd,a,b,x,X,Y,O){
+MLY_maha <- function(yd,a,b,x,X,Y,O){
     O11 <- O[,1]; O22 <- O[,2]; O12 <- O[,3]
     (X-x)*(O11*(X-x)+O12*(Y-a-b*x)) + (Y-a-b*x)*(O12*(X-x)+O22*(Y-a-b*x))
 }
